@@ -288,7 +288,7 @@ typedef union YYSTYPE {
 	TokenValuePairs* atvtype;
 } YYSTYPE;
 /* Line 1240 of yacc.c.  */
-#line 291 "y.tab.h"
+#line 291 "parser.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
