@@ -34,12 +34,6 @@
 
 START_NAMESPACE( Aqsis )
 
-#ifdef AQSIS_SYSTEM_MACOSX 
-// Workaround for Mac OS X gcc 2.95 compiler error -
-// "Fixup [linenumber] too large for field width of 16 bits"
-#pragma CC_OPT_OFF
-#endif
-
 void CqShaderVM::SO_exp()
 {
     AUTOFUNC;
@@ -282,19 +276,19 @@ void CqShaderVM::SO_pDeriv()
 
 void CqShaderVM::SO_frandom()
 {
-    AUTOFUNC;
+    VARFUNC;
     FUNC( type_float, m_pEnv->SO_frandom );
 }
 
 void CqShaderVM::SO_crandom()
 {
-    AUTOFUNC;
+    VARFUNC;
     FUNC( type_color, m_pEnv->SO_crandom );
 }
 
 void CqShaderVM::SO_prandom()
 {
-    AUTOFUNC;
+    VARFUNC;
     FUNC( type_point, m_pEnv->SO_prandom );
 }
 
@@ -1293,10 +1287,5 @@ void CqShaderVM::SO_occlusion()
     TEXTURE3( type_float, m_pEnv->SO_occlusion );
 }
 
-
-#ifdef AQSIS_SYSTEM_MACOSX
-#pragma CC_OPT_RESTORE
-#endif
-
 END_NAMESPACE( Aqsis )
 //---------------------------------------------------------------------
